@@ -4,7 +4,7 @@
 import time
 import board
 import busio
-import adafruit_bme280
+from adafruit_bme280 import basic as adafruit_bme280
 
 # Create sensor object, using the board's default I2C bus.
 i2c = busio.I2C(board.GP1, board.GP0)  # SCL, SDA
